@@ -55,6 +55,7 @@ module.exports = {
         "julia",
         "kubectl",
         "nbgv",
+        "nightscout",
         "node",
         "os",
         "owm",
@@ -71,6 +72,8 @@ module.exports = {
         "terraform",
         "text",
         "time",
+        "wifi",
+        "winreg",
         "ytm",
       ],
     },
