@@ -52,8 +52,8 @@ type cache interface {
 	init(home string)
 	close()
 	get(key string) (string, bool)
-	// ttl in seconds
-	set(key, value string, ttl int64)
+	// ttl in minutes
+	set(key, value string, ttl int)
 }
 
 type environmentInfo interface {
@@ -80,6 +80,7 @@ type environmentInfo interface {
 	getBatteryInfo() ([]*battery.Battery, error)
 	getShellName() string
 	getWindowTitle(imageName, windowTitleRegex string) (string, error)
+	getWindowsRegistryKeyValue(regPath, regKey string) (string, error)
 	doGet(url string, timeout int) ([]byte, error)
 	hasParentFilePath(path string) (fileInfo *fileInfo, err error)
 	isWsl() bool
